#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor el%{nil}
%if "%{flavor}" == "testsuite"
%global psuffix -testsuite
%elif "%{flavor}" == "el"
%global psuffix -el
%else
%global psuffix %{nil}
%endif
Name:           autoconf%{?psuffix}
Version:        2.71
Release:        2.2
Summary:        A GNU Tool for Automatically Configuring Source Code
License:        GPL-3.0-or-later
URL:            https://www.gnu.org/software/autoconf
Source0:        https://ftp.gnu.org/gnu/autoconf/autoconf-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/autoconf/autoconf-%{version}.tar.xz.sig
Source9:        autoconf.keyring
Patch0:         autoreconf-ltdl.diff
Patch1:         fix-testsuite-failures-with-bash-5.2.patch
BuildRequires:  help2man
BuildRequires:  m4 >= 1.4.6
BuildArch:      noarch
%if "%{name}" == "autoconf"
Requires:       info
Requires:       m4 >= 1.4.6
Requires:       perl-base >= 5.6
%endif
%if "%{name}" == "autoconf-testsuite"
BuildRequires:  gcc-c++
%endif
%if "%{name}" == "autoconf-el"
%global site_lisp %{_datadir}/emacs/site-lisp
BuildRequires:  emacs-nox
BuildRequires:  gcc-c++
Enhances:       emacs
%endif

%description
GNU Autoconf is a tool for configuring source code and makefiles. Using
autoconf, programmers can create portable and configurable packages,
because the person building the package is allowed to specify various
configuration options.

You should install autoconf if you are developing software and would
like to create shell scripts to configure your source code packages.

Note that the autoconf package is not required for the end user who may
be configuring software with an autoconf-generated script; autoconf is
only required for the generation of the scripts, not their use.

%prep
%setup -q -n autoconf-%{version}
%patch0
%patch1 -p1

%build
%configure
%make_build

%if "%{name}" == "autoconf-testsuite"
%check
trap 'test $? -ne 0 && cat tests/testsuite.log' EXIT
%make_build check

%install
%elif "%{name}" == "autoconf-el"

%install
mkdir -p %{buildroot}%{site_lisp}
install -c -m 644 lib/emacs/autoconf-mode.el  %{buildroot}%{site_lisp}/autoconf-mode.el
install -c -m 644 lib/emacs/autoconf-mode.elc %{buildroot}%{site_lisp}/autoconf-mode.elc
install -c -m 644 lib/emacs/autotest-mode.el  %{buildroot}%{site_lisp}/autotest-mode.el
install -c -m 644 lib/emacs/autotest-mode.elc %{buildroot}%{site_lisp}/autotest-mode.elc
sed 's/^;//' > %{buildroot}%{site_lisp}/suse-start-%{name}.el <<\EOF
;;; %{site_lisp}/suse-start-%{name}.el
;
(autoload 'autoconf-mode "autoconf-mode"
          "Major mode for editing autoconf files." t)
(add-to-list 'auto-mode-alist
             '("configure\\.\\(ac\\|in\\)\\'" . autoconf-mode))
;
(autoload 'autotest-mode "autotest-mode"
          "Major mode for editing autotest files." t)
(add-to-list 'auto-mode-alist
             '("\\.at\\'" . autotest-mode))
;
;;; %{site_lisp}/suse-start-%{name}.el ends here
EOF
%else

%install
%make_install
%endif

%if "%{name}" == "autoconf"
%files
%doc AUTHORS NEWS README TODO
%license COPYING
%{_bindir}/*
%{_datadir}/autoconf
%{_infodir}/*.gz
%{_mandir}/man1/*.gz
%endif

%if "%{name}" == "autoconf-el"
%files
%license COPYING
%{site_lisp}/*.el
%{site_lisp}/*.elc
%endif

%changelog
* Thu Oct 27 2022 Valentin Lefebvre <valentin.lefebvre@suse.com>
- fix testsuite failure by bash 5.2 update
  * [fix-testsuite-failures-with-bash-5.2.patch]
* Mon Mar 28 2022 Dirk Müller <dmueller@suse.com>
- convert to use _multibuild
- fix keyring gpg validation
* Fri Mar 12 2021 Dirk Müller <dmueller@suse.com>
- use https urls
* Sat Jan 30 2021 Andreas Stieger <andreas.stieger@gmx.de>
- autoconf 2.71:
  * Compilers that support C99 but not C2011 are detected correctly
  * Compatibility improved with clang and Oracle C++
  * Compatibility restored with automake's rules for regenerating
    configure
  * Compatibility restored with old versions of std-gnu11.m4
- dropped upstream patches:
  * prog-c99-fix-typo.patch
  * restore-compatibility-gnu11.patch
  * autom4te-always-update-output-file.patch
  * handle-gettext-alone.patch
* Sat Jan 16 2021 Dirk Müller <dmueller@suse.com>
- add autom4te-always-update-output-file.patch to fix testsuite
  failures
- handle-gettext-alone.patch: support GNU_GETTEXT alone being called
  again
- add prog-c99-fix-typo.patch: fix typo in C99 detection
- add restore-compatibility-gnu11.patch: restore compatibility in GNU11
  mode
* Sun Dec 13 2020 Andreas Stieger <andreas.stieger@gmx.de>
- autoconf 2.70:
  * Warnings about obsolete constructs are now on by default,
    these warnings can be turned off with -Wno-obsolete
  * Many macros have become pickier about argument quotation
  * Many macros no longer AC_REQUIRE as many other macros as they
    used to, may expose several classes of latent bugs
  * More macros use config.sub and config.guess internally
  * Setting CC to a C++ compiler is no longer supported
  * Running configure tests with warnings promoted to errors is
    not supported
  * Including confdefs.h manually may cause test failures
  * Older versions of automake and aclocal (< 1.8) are no longer
    supported
  * AC_CONFIG_SUBDIRS no longer directly supports Cygnus configure
  * AC_CHECK_HEADER and AC_CHECK_HEADERS only do a compilation test
  * AC_INCLUDES_DEFAULT assumes an ISO C90 compliant C implementation
  * AS_ECHO and AS_ECHO_N unconditionally use ‘printf’
  * Configure scripts require support for $( ... ) command
    substitution
  * AC_INIT now trims extra white space from its arguments
  * Macros that take whitespace-separated lists as arguments
    now always expand macros within those arguments
  * AC_FUNC_STRERROR_R assumes strerror_r is unavailable if it’s
    not declared
  * AC_OPENMP can’t be used if you have files named ‘mp’ or ‘penmp’
  * Configure scripts now support a ‘--runstatedir’ option
  * autoreconf will now run gtkdocize and intltoolize when appropriate
  * autoreconf now recognizes AM_GNU_GETTEXT_REQUIRE_VERSION
  * autoheader handles secondary config headers better
  * AC_PROG_CC now enables C2011 mode if the compiler supports it
  * New macro AC_C__GENERIC tests for C2011 _Generic support
  * AC_C_VARARRAYS has been aligned with C2011.
  * New macro AC_CONFIG_MACRO_DIRS
  * AC_USE_SYSTEM_EXTENSIONS knows about more extensions to enable
  * New compatibility macro AC_CHECK_INCLUDES_DEFAULT
  * AC_REQUIRE_AUX_FILE has been improved
  * AC_PROG_LEX has an option to not look for yywrap
  * Use of the long-deprecated name ‘configure.in’ for the autoconf
    input file now elicits a warning in the “obsolete” category
  * Use of the undocumented internal shell variables $as_echo and
    $as_echo_n now elicits a warning in the “obsolete” category.
    The macros AS_ECHO and AS_ECHO_N should be used instead.
  * autoconf will now issue warnings (in the “syntax” category)
    if the input file is missing a call to AC_INIT and/or AC_OUTPUT
  * autoconf will now issue warnings (in the “syntax” category)
    for a non-literal URL argument to AC_INIT, and for a TARNAME
    argument to AC_INIT which is either non-literal or contains
    characters that should not be used in file names (e.g. ‘*’).
  * AC_PROG_CC_STDC, AC_PROG_CC_C89, AC_PROG_CC_C99 are now
    obsolete. Applications should use AC_PROG_CC.
  * AC_HEADER_STDC and AC_HEADER_TIME are now stubs.
  * AC_DIAGNOSE, AC_FATAL, AC_WARNING, and _AC_COMPUTE_INT are now
    replaced with modern equivalents by autoupdate.
  * AC_CONFIG_HEADER is now diagnosed as obsolete, and replaced with
    AC_CONFIG_HEADERS by autoupdate.
  * The macro AC_OBSOLETE is obsolete.
  * Man pages for config.guess and config.sub are no longer provided
  * Bug fixes for compatibility with current Automake, Libtool,
    Perl, Texinfo, and shells
  * Compatibility fixes for compilers and build environments
  * Various autotest enhancements
- drop upstream patches:
  * autoconf-perl-5.17-fixes.patch
  * port-tests-to-bash-5.patch
  * ac-header-major.patch
- remove obsolete texinfo packaging macros
* Tue Nov  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix testsuite with Bash 5, add port-tests-to-bash-5.patch
* Wed Oct 30 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Require perl-base instead of perl, none of the additional modules
  are required.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Mon Aug  6 2018 schwab@suse.de
- ac-header-major.patch: port AC_HEADER_MAJOR to glibc 2.25
- Use %%license for COPYING
* Wed Mar 15 2017 dimstar@opensuse.org
- Also BuildRequire m4 for autoconf-el: it was wrongly assumed that
  the two spec files would be in sync (but pre_checkin only syncs
  the Version: and .changes file).
* Thu Feb  9 2017 dimstar@opensuse.org
- Explicitly buildrequire m4: there is a plan to remove it from the
  implicit buildroot configuration (just like autoconf itself is
  no longer part of a long time already).
* Tue Sep  1 2015 dimstar@opensuse.org
- Add autoconf-perl-5.17-fixes.patch: autoscan: port to perl 5.17.
* Fri Mar 13 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg signature
- Correct info file dependencies
* Wed Mar 20 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Nov 27 2012 pth@suse.de
- Repackage with bzip2 so that the package can be built for older
  distributions.
* Fri Apr 27 2012 pth@suse.de
- Fix .changes file.
* Thu Apr 26 2012 pth@suse.de
- Update to 2.69:
  * Noteworthy changes in release 2.69 (2012-04-24) [stable]
  * * Autoconf now requires perl 5.6 or better (but generated
    configure scripts continue to run without perl).
  * Noteworthy changes in release 2.68b (2012-03-01) [beta] Released
    by Eric Blake, based on git versions 2.68.*.
  * * Autoconf-generated configure scripts now unconditionally
    re-execute themselves with $CONFIG_SHELL, if that's set in the
    environment.
  * * The texinfo documentation no longer specifies "front-cover" or
    "back-cover" texts, so that it may now be included in Debian's
    "main" section.
  * * Support for the Go programming language has been added.  The new
    macro AC_LANG_GO sets variables GOC and GOFLAGS.
  * * AS_LITERAL_IF again treats '=' as a literal.  Regression
    introduced in 2.66.
  * * The macro AS_EXECUTABLE_P, present since 2.50, is now
    documented.
  * * Macros
  - AC_PROG_LN_S and AS_LN_S now fall back on 'cp -pR' (not 'cp -p')
    if 'ln -s' does not work.  This works better for symlinks to
    directories.
  - New macro AC_HEADER_CHECK_STDBOOL.
  - New and updated macros for Fortran support:
    AC_FC_CHECK_BOUNDS to enable array bounds checking
    AC_F77_IMPLICIT_NONE and AC_FC_IMPLICIT_NONE to disable implicit integer
    AC_FC_MODULE_EXTENSION to compute the Fortran 90 module name extension
    AC_FC_MODULE_FLAG for the Fortran 90 module search path flag
    AC_FC_MODULE_OUTPUT_FLAG for the Fortran 90 module output directory flag
    AC_FC_PP_SRCEXT for preprocessed Fortran source files extensions
    AC_FC_PP_DEFINE for the Fortran preprocessor define flag
* Sun Dec 18 2011 sweet_f_a@gmx.de
- correct license and style (prepare_spec)
- minor build fixes, avoid deprecated macros to be more portable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Jan 31 2011 pth@suse.de
- Use 2.68 everywhere in specfile.
- Use %%%%configure macro in spec file.
* Mon Jan 31 2011 pth@suse.de
- Cosmetic changes to spec file
* Fri Dec 10 2010 coolo@novell.com
- update to 2.68 to include the patch
  * * AC_MSG_ERROR (and AS_ERROR) can once again be followed immediately by
  `dnl'.  Regression introduced in 2.66.
  * * AC_INIT again allows URLs with '?' for its BUG-REPORT argument.
  Regression introduced in 2.66.
  * * AC_REPLACE_FUNCS again allows a non-literal argument, such as a shell
  variable that expands to a list of functions to check.  Regression
  introduced in 2.66.
  * * AT_BANNER() with empty argument will cause visual separation from previous
  test category.
  * * The macros AC_PREPROC_IFELSE, AC_COMPILE_IFELSE, AC_LINK_IFELSE, and
  AC_RUN_IFELSE now warn if the first argument failed to use
  AC_LANG_SOURCE or AC_LANG_PROGRAM to generate the conftest file
  contents.  A new macro AC_LANG_DEFINES_PROVIDED exists if you have
  a compelling reason why you cannot use AC_LANG_SOURCE but must
  avoid the warning.
  * * Newly obsolete macros
  The following macros have been marked obsolete.  New programs
  should use the corresponding Gnulib modules.  Gnulib not only
  detects a larger set of portability problems with these functions,
  but also provides complete workarounds.
    AC_FUNC_ERROR_AT_LINE  AC_FUNC_LSTAT_FOLLOWS_SLASHED_SYMLINK
    AC_FUNC_MKTIME  AC_FUNC_STRTOD
* Sun Sep 19 2010 andrea@opensuse.org
- added patch autoconf-2.67-fix_dnl.patch to fix regression in
  AC_MSG_ERROR expansion (undefined macro: AS_MESSAGE_LOG_FDdnl)
* Wed Aug 18 2010 pth@suse.de
- Update to 2.67:
  * New macro AC_FC_LINE_LENGTH to accept long Fortran source code
    lines.
  * AC_PREPROC_IFELSE now keeps the preprocessed output in the
    conftest.i file for inspection by the commands in the
    ACTION-IF-TRUE argument.
  * autoreconf passes warning flags to new enough versions of
    aclocal.
  * Running an Autotest testsuite in parallel mode no longer triggers
    a race condition that could cause the testsuite run to end early,
    fixing a sporadic failure in autoconf's own testsuite.  Bug
    present since introduction of parallel tests in 2.63b.
  Major changes in Autoconf 2.66 (2010-07-02) [stable]
  * AC_FUNC_MMAP works in C++ mode again.  Regression introduced in
    2.65.
  * Use of m4_divert without a named diversion now issues a syntax
    warning, since it is seldom right to change diversions behind
    autoconf's back.
  * The macros AC_TYPE_INT8_T, AC_TYPE_INT16_T, AC_TYPE_INT32_T, and
    AC_TYPE_INT64_T work again.  Regression introduced in 2.65.
  * AC_PROG_INSTALL correctly uses `shtool' again.  Regression
    introduced in 2.64.
  * Autoconf should work on EBCDIC hosts.
  * AC_CHECK_DECL and AC_CHECK_DECLS accept optional function
    argument types for overloaded C++ functions.
  * AS_SET_CATFILE accepts nonliterals in its variable name argument
    now.
  * Autotest testsuites accept an option --recheck to rerun tests
    that failed or passed unexpectedly during the last non-debug
    testsuite run.
  * AC_ARG_ENABLE and AC_ARG_WITH now also accept `+' signs in
    `--enable-*' and `--with-*' arguments, converting them to
    underscores for the variable names.
  * In configure scripts, loading CONFIG_SITE no longer searches
    PATH, and problems in loading the configuration site files are
    diagnosed.
  * Autotest testsuites may optionally provide colored test results.
  * The previously undocumented Autotest macros AT_ARG_OPTION and
    AT_ARG_OPTION_ARG have seen bug fixes and are documented now.
    AT_ARG_OPTION has been changed in that the negative of a long
    option --OPTION is now --no-OPTION rather than --noOPTION.
  * The macro AS_LITERAL_IF is slightly more conservative; text
    containing shell quotes are no longer treated as literals.
    Furthermore, a new macro, AS_LITERAL_WORD_IF, adds an additional
    level of checking that no whitespace occurs in literals.
  * The macros AS_TR_SH and AS_TR_CPP no longer expand their results.
  * The following macros are now documented:
    AS_BOX
  * New macro AC_FC_FIXEDFORM to accept fixed-form Fortran.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Mon May 31 2010 coolo@novell.com
- add empty install section
* Fri May 28 2010 coolo@novell.com
- split out test suite that takes 95%% of the build time
* Wed Feb 17 2010 poletti.marco@gmail.com
- Update to 2.65
  * * Autoconf is now licensed under the GPLv3+.
  * * The manual is now shipped under the terms of the GNU FDL 1.3.
  * * config.status now provides a --config option to produce the configuration.
  * * Autoconf now requires GNU M4 1.4.6 or later. GNU M4 1.4.13 or
    later is recommended.
  * * Autotest testsuites accept an option --jobs[=N] for parallel testing.
    This feature is still in testing, and may not work on every
    platform, help in improving it would be appreciated.
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
* Fri Jul 17 2009 dominique-obs@leuenberger.net
- Add autoconf-xfail-test27.patch
  + It skips test 27 ([autom4te preselections]) as it's an
    incompatibility between autoconf 2.63 and automake 1.11
    ! This patch needs to be removed with autoconf 2.64 again !
* Wed Sep 10 2008 schwab@suse.de
- Update to autoconf 2.63.
  * * AC_C_BIGENDIAN does not mistakenly report "universal" for some
    bigendian hosts, a regression introduced with universal binary
    support in 2.62.
  * * AC_PATH_X now includes /lib64 and /usr/lib64 in its list of default
    library directories.
  * * AC_USE_SYSTEM_EXTENSIONS no longer conflicts with an external
    AC_DEFINE([__EXTENSIONS__]).  This fixes a regression introduced in
    2.62 when using macros such as AC_AIX that were made obsolete in
    favor of the more portable AC_USE_SYSTEM_EXTENSIONS.
  * * AC_CHECK_TARGET_TOOLS is usable in the non-cross-compile case.
  * * Newly obsolete macros
    The following macro has been marked obsolete, since current porting
    targets can safely assume C89 semantics that signal handlers return
    void.  We have no current plans to remove the macro.
    AC_TYPE_SIGNAL
  * * The macros m4_map and m4_map_sep now ignore any list elements
    consisting of just empty quotes, and m4_map_sep now expands its
    separator.  This fixes a regression in 2.62 when these macros were
    first documented, for the sake of clients expecting the semantics
    that these macros had prior to that time.  The new macros m4_mapall
    and m4_mapall_sep, along with extra quoting of the separator, can
    be used to get the semantics that m4_map_sep had in 2.62.
  * * Clients of m4_expand, such as AS_HELP_STRING and AT_SETUP, can now
    handle properly quoted but otherwise unbalanced parentheses (for
    some macros, this fixes a regression in 2.62).
  * * Two new quadrigraphs have been introduced: @{:@ for (, and @:}@ for ),
    allowing the output of unbalanced parentheses in more contexts.
  * * The following m4sugar macros are new:
    m4_joinall  m4_mapall  m4_mapall_sep  m4_reverse  m4_set_add
    m4_set_add_all  m4_set_contains  m4_set_contents  m4_set_delete
    m4_set_difference  m4_set_dump  m4_set_empty  m4_set_foreach
    m4_set_intersection  m4_set_list  m4_set_listc  m4_set_remove
    m4_set_size  m4_set_union
  * * The following m4sugar macros now accept multiple arguments, as is the
    case with underlying m4:
    m4_defn  m4_popdef  m4_undefine
  * * The following m4sugar macros now guarantee linear scaling; they
    previously had linear scaling with m4 1.6 but quadratic scaling
    when using m4 1.4.x.  All macros built on top of these also gain
    the scaling improvements.
    m4_bmatch  m4_bpatsubsts  m4_case  m4_cond  m4_do  m4_dquote_elt
    m4_foreach  m4_join  m4_list_cmp  m4_map  m4_map_sep  m4_max
    m4_min  m4_shiftn
  * * AT_KEYWORDS once again performs expansion on its argument, such that
    AT_KEYWORDS([m4_if([$1], [], [default])]) no longer complains about
    the possibly unexpanded m4_if [regression introduced in 2.62].
  * * Config header templates `#undef UNDEFINED /* comment */' do not lead to
    nested comments any more; regression introduced in 2.62.
* Thu Jul 17 2008 schwab@suse.de
- Revert AC_C_BIGENDIAN change for now.
- Fix config header substitution.
* Wed Apr  9 2008 schwab@suse.de
- Update to autoconf 2.62.
  <http://git.savannah.gnu.org/gitweb/?p=autoconf.git;a=blobdiff;f=NEWS;h=ef008867d725a89b743b20eeba97bec09e906fd6;hp=2a49e0feb1b4101bb5252fdd137992ec49f468fa>
* Mon Mar 10 2008 schwab@suse.de
- Fix spurious testsuite failure.
* Tue Feb 19 2008 schwab@suse.de
- Fix undefined behaviour in AC_FUNC_MKTIME test.
* Fri Jun  1 2007 schwab@suse.de
- Relax m4 requirement to work around autobuild bug.
* Mon Apr  2 2007 schwab@suse.de
- Fix spurious testsuite failure.
* Sun Mar 25 2007 schwab@suse.de
- Display testsuite log on failure.
* Wed Dec 13 2006 schwab@suse.de
- Handle old style libltdl macros.
* Mon Dec  4 2006 schwab@suse.de
- Update to autoconf 2.61.
  * * New macros AC_C_FLEXIBLE_ARRAY_MEMBER, AC_C_VARARRAYS.
  * * AC_ARG_ENABLE and AC_ARG_WITH now allow '.' in feature and package names.
* Wed Aug  2 2006 schwab@suse.de
- Split off autoconf-el.
* Thu Jul 20 2006 schwab@suse.de
- Fix testsuite.
* Tue Jun 27 2006 schwab@suse.de
- Update to autoconf 2.60, see
  <http://cvs.savannah.gnu.org/viewcvs/autoconf/autoconf/NEWS?r1=1.388&r2=1.322>.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jun 18 2004 schwab@suse.de
- Require exact version of m4.
* Thu Nov 13 2003 schwab@suse.de
- Update to autoconf 2.59, incorporates last change.
* Mon Nov 10 2003 schwab@suse.de
- Fix abs_srcdir.
* Tue Nov  4 2003 schwab@suse.de
- Update to autoconf 2.58.
* Thu Sep 18 2003 schwab@suse.de
- Downgrade flock failure to a warning [#26962].
* Mon Sep  8 2003 schwab@suse.de
- Add patch to serialize access to autom4te cache file [#26962].
* Mon May 12 2003 schwab@suse.de
- Add %%defattr.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Thu Dec  5 2002 schwab@suse.de
- Update to autoconf 2.57.
  * Bug fixes for problems with AIX linker, with freestanding C compilers,
    with GNU m4 limitations, and with obsolete copies of GNU documents.
* Fri Nov 15 2002 schwab@suse.de
- Update to autoconf 2.56.
* Tue Jun 11 2002 schwab@suse.de
- Fix missing info dir entries.
* Mon May 13 2002 schwab@suse.de
- Fix invalid node name in docs [#16078].
* Fri Apr 12 2002 schwab@suse.de
- Remove g77 from neededforbuild.
* Mon Apr  8 2002 schwab@suse.de
- Run automake last in autoreconf.
* Sun Apr  7 2002 schwab@suse.de
- Fix _AC_SRCPATHS.
* Thu Apr  4 2002 schwab@suse.de
- Fix _AS_PATH_WALK.
* Tue Apr  2 2002 schwab@suse.de
- Fix premature expansion in m4_bmatch.
* Sat Mar 30 2002 schwab@suse.de
- Handle libltdl in autoreconf.
- Run automake after aclocal in autoreconf.
* Fri Mar 15 2002 schwab@suse.de
- Handle gettext 0.11 in autoreconf.
* Sat Mar  9 2002 schwab@suse.de
- Update to autoconf 2.53.
* Sat Jul 21 2001 schwab@suse.de
- Always set {host,build,target}_alias.
* Thu Jul 19 2001 schwab@suse.de
- Update to autoconf 2.52.
* Mon Jun 11 2001 olh@suse.de
- recognize ppc64
* Tue May 22 2001 schwab@suse.de
- Update to autoconf 2.50.
- Add Buildroot.
* Fri Mar 23 2001 schwab@suse.de
- Add m4 as neededforbuild.
- Require m4 and gawk.
* Wed Mar 21 2001 schwab@suse.de
- Set F77 to g77 during `make check'.
* Wed Feb 21 2001 schwab@suse.de
- Fix AC_PROC_CXXCPP.
- Add %%suse_update_config.
- Don't mark acconfig.h as %%config.
- Run testsuite.
* Thu Jun  1 2000 kukuk@suse.de
- Add more docu, fill out group tag
* Mon May  1 2000 kukuk@suse.de
- Use infodir macro
* Fri Mar 24 2000 schwab@suse.de
- Fix conflicting declaration of exit.
* Tue Jan 18 2000 schwab@suse.de
- Undefine m4 macro `symbols' (new builtin in m4 1.4o).
* Mon Dec  6 1999 schwab@suse.de
- Discard output from `type -p'.
* Thu Dec  2 1999 schwab@suse.de
- Make sure tempfiles are always removed.
- Fix some quoting bugs in shell scripts.
* Thu Nov  4 1999 ro@suse.de
- fixed for alphaev6
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug 25 1999 kukuk@suse.de
- Specfile cleanup
* Fri Jan 15 1999 ro@suse.de
- update to 2.13
* Thu Jul 23 1998 werner@suse.de
- Make auto*.sh more secure and use mktemp if avaliable
* Wed Jan 22 1997 florian@suse.de
- update to version 2.12
